@@ -98,6 +98,9 @@ sub _return_html ( $self, $req ) {
     if ( !$self->{cache}->{app}->{$locale}->{html} ) {
         my $resources = [ $self->ext_resources->@* ];
 
+        # pcoreApi
+        push $resources->@*, q[<script src="/static/pcoreApi.js" integrity="" crossorigin="anonymous"></script>];
+
         # FontAwesome
         push $resources->@*, Pcore::Share::WWW->fontawesome;
 
@@ -449,7 +452,7 @@ sub _prepare_js ( $self, $js ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    2 | 361                  | ControlStructures::ProhibitPostfixControls - Postfix control "while" used                                      |
+## |    2 | 364                  | ControlStructures::ProhibitPostfixControls - Postfix control "while" used                                      |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
